Struct CosmicA11yManagerV1

pub struct CosmicA11yManagerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
a11y global

Manager to toggle accessibility features.

See also the Event enum for this interface.

Implementations

Source

impl CosmicA11yManagerV1

pub fn set_magnifier(&self, active: ActiveState)

Set the screen magnifier on or off

Sets the state of the screen magnifier.

The client must not assume any requested changes are actually applied and should wait until the next magnifier event before updating it’s UI.

pub fn set_screen_filter(&self, inverted: ActiveState, filter: Filter)

Set screen filtering

Set the parameters for screen filtering.

If the filter is set to unknown, the compositor MUST not change the current state of the filter. This is to allow clients to update the inverted state, even if they don’t know about the current active filter.

The client must not assume any requested changes are actually applied and should wait until the next screen_filter event before updating it’s UI.

Send this request will raised a “deprecated” protocol error, if version 3 or higher was bound. Use set_screen_filter2 instead.

pub fn set_screen_filter2( &self, inverted: ActiveState, filter: Filter, filter_state: ActiveState, )

Set screen filtering

Set the parameters for screen filtering.

If the filter is set to unknown, the compositor MUST not change the currently set filter. This is to allow clients to update the inverted state or toggle the screen filter, even if they don’t know about the currently selected filter.

The client must not assume any requested changes are actually applied and should wait until the next screen_filter event before updating it’s UI.

The “deprecated” protocol error is raised, if “disabled” is set for “filter”.